// Copyright 2016 Open Source Robotics Foundation, Inc.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

#include <chrono>

#include "minimal_composition/publisher_node.hpp"
#include "rclcpp/rclcpp.hpp"
#include "std_msgs/msg/string.hpp"

PublisherNode::PublisherNode()
: Node("publisher_node"), count_(0)
{
  publisher_ = create_publisher<std_msgs::msg::String>("topic");
  timer_ = create_wall_timer(
    std::chrono::milliseconds(500), std::bind(&PublisherNode::on_timer, this));
}

void PublisherNode::on_timer()
{
  auto message = std_msgs::msg::String();
  message.data = "Hello, world! " + std::to_string(count_++);
  printf("Publisher: [%s]\n", message.data.c_str());
  publisher_->publish(message);
}

#include "class_loader/class_loader_register_macro.h"

CLASS_LOADER_REGISTER_CLASS(PublisherNode, rclcpp::Node)
